pyparsing.Suppress

Module pyparsing :: Class Suppress |
[frames] | no frames]

# Class Suppress

source code

         object --+
                  |
      ParserElement --+
                      |
    ParseElementEnhance --+
                          |
             TokenConverter --+
                              |
                             Suppress

Converter for ignoring the results of a parsed expression.

Nested Classes
Inherited from `ParserElement`: `literalStringClass`

Instance Methods
postParse(self, instring, loc, tokenlist) | source code
suppress(self) Suppresses the output of this `ParserElement`; useful to keep punctuation from cluttering up returned output. | source code
Inherited from `TokenConverter`: `__init__` Inherited from `ParseElementEnhance`: `__str__`, `checkRecursion`, `ignore`, `leaveWhitespace`, `parseImpl`, `streamline`, `validate` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__hash__`, `__invert__`, `__mul__`, `__ne__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__rne__`, `__ror__`, `__rsub__`, `__rxor__`, `__sub__`, `__xor__`, `addCondition`, `addParseAction`, `copy`, `parseFile`, `parseString`, `parseWithTabs`, `preParse`, `runTests`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setFailAction`, `setName`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `ParserElement`: `enablePackrat`, `inlineLiteralsUsing`, `resetCache`, `setDefaultWhitespaceChars`

Class Variables
| __slotnames__ = ``[``]``
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`, `verbose_stacktrace`

Properties
Inherited from `object`: `__class__`

Method Details

### postParse(self, instring, loc, tokenlist) | source code
Overrides: ParserElement.postParse

### suppress(self) | source code
Suppresses the output of this `ParserElement`; useful to keep punctuation from cluttering up returned output. Overrides: ParserElement.suppress (inherited documentation)